/*
 * Copyright 2006 IONA Technologies
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.codehaus.xharness.exceptions;

import org.apache.tools.ant.BuildException;


/**
 * Exception that signals a failed assertion.
 * 
 * @author Gregor Heine
 */
public class AssertionWarningException extends BuildException {
    private static final long serialVersionUID = 
        AssertionWarningException.class.getName().hashCode();

    /**
     * Constructs an assertion exception with no descriptive information.
     */
    public AssertionWarningException() {
        super();
    }

    /**
     * Constructs an exception with the given descriptive message.
     *
     * @param msg A description of or information about the failed assertion.
     *            Should not be <code>null</code>.
     */
    public AssertionWarningException(String msg) {
        super(msg);
    }

    /**
     * Constructs an exception with the given message and exception as
     * a root cause.
     *
     * @param message A description of or information about the failed assertion.
     * @param cause The exception that caused the assertion to fail.
     */
    public AssertionWarningException(String message, Throwable cause) {
        super(message, cause);
    }
}
